

#ifndef MCMC2_INCLUDE
#define MCMC2_INCLUDE
/*------------------------------------------------------
 Maximum likelihood estimation 
 of migration rate  and effectice population size
 using a Metropolis-Hastings Monte Carlo algorithm                            
 -------------------------------------------------------                        
 M C M C 2   R O U T I N E S 
 
 Tree changing routines
 
 
 Peter Beerli 1996, Seattle
 beerli@csit.fsu.edu
 
Copyright 2001 Peter Beerli and Joseph Felsenstein
 
$Id: mcmc2.h,v 1.4 2003/11/04 16:12:09 beerli Exp $
-------------------------------------------------------*/

extern void coalesce1p (proposal_fmt * proposal);
extern void pretendcoalesce1p (proposal_fmt * proposal);

#endif /*MCMC2_INCLUDE */
